=======
History
=======

1.0.0 (2021-11-27)
------------------

* Major release.

This is the first major release of pydeflate.

- This new version effectively breaks any compatibility with previous versions
  of pydeflate.
- This version is a complete rewrite of the package. Please refer to the
  documentation for information on how pydeflate works
- The basic functionality of pydeflate can now be considered to be settled. 
  Further releases to pydeflate will extend what is possible, without altering
  the basic way in which pydeflate works.


0.1.4 (2021-04-21)
------------------

* Minor release.

This is a minor update to fix a couple of small errors in doc strings.
It also adds unit testing for updating the underlying data.



0.1.3 (2021-04-21)
------------------

* Minor release.

This version achieves the basic task at hand. It does not yet have full testing.



0.1.2 (2021-04-21)
------------------

* Minor release.

This version achieves the basic task at hand. It does not yet have full testing.



0.1.1 (2021-04-21)
------------------

* Minor release.

This version has been yanked.



0.1.0 (2021-04-21)
------------------

* First release on PyPI.

This version has been yanked.






